"use strict";

require("../../mocha-config");

var UsersAdminPanel = require('../../../../main/js/gui/admin/UsersAdminPanel');
var SecurityError = require('../../../../main/js/SecurityError');
var ServerConnector = require('../../ServerConnector-mock');
var logger = require('../../logger');

var assert = require('assert');

describe('UsersAdminPanel', function () {

  describe('init', function () {
    it('default', function () {
      helper.loginAsAdmin();
      var usersTab;
      var project;
      return ServerConnector.getProject().then(function (result) {
        project = result;
        return ServerConnector.getConfiguration();
      }).then(function (configuration) {
        usersTab = new UsersAdminPanel({
          element: testDiv,
          project: project,
          configuration: configuration
        });
        return usersTab.init();
      }).then(function () {
        assert.equal(0, logger.getWarnings().length);
        return usersTab.destroy();
      });
    });
    it('user without access', function () {
      var usersTab;
      var project;
      var oldFun = ServerConnector.getUsers;
      ServerConnector.getUsers = function () {
        return Promise.reject(new SecurityError("Access denied."));
      };
      return ServerConnector.getProject().then(function (result) {
        project = result;
        return ServerConnector.getConfiguration();
      }).then(function (configuration) {
        usersTab = new UsersAdminPanel({
          element: testDiv,
          project: project,
          configuration: configuration
        });
        return usersTab.init();
      }).then(function () {
        assert.equal(0, logger.getWarnings().length);
        assert.ok(usersTab.getElement().innerHTML.indexOf("no privilege") >= 0);
        return usersTab.destroy();
      }).finally(function () {
        ServerConnector.getUsers = oldFun;
      });
    });
  });

  it('refresh', function () {
    helper.loginAsAdmin();
    var mapTab;
    var project;
    return ServerConnector.getProject().then(function (result) {
      project = result;
      return ServerConnector.getConfiguration();
    }).then(function (configuration) {
      mapTab = new UsersAdminPanel({
        element: testDiv,
        project: project,
        configuration: configuration
      });
      return mapTab.init();
    }).then(function () {
      return mapTab.onRefreshClicked();
    }).then(function () {
      return mapTab.destroy();
    });
  });

  it('showEditDialog', function () {
    helper.loginAsAdmin();
    var mapTab;
    var project;
    return ServerConnector.getProject().then(function (result) {
      project = result;
      return ServerConnector.getConfiguration();
    }).then(function (configuration) {
      mapTab = new UsersAdminPanel({
        element: testDiv,
        project: project,
        configuration: configuration
      });
      return mapTab.init();
    }).then(function () {
      return mapTab.showEditDialog("anonymous");
    }).then(function () {
      return mapTab.destroy();
    });
  });
  it('onAddClicked', function () {
    helper.loginAsAdmin();
    var mapTab;
    var project;
    return ServerConnector.getProject().then(function (result) {
      project = result;
      return ServerConnector.getConfiguration();
    }).then(function (configuration) {
      mapTab = new UsersAdminPanel({
        element: testDiv,
        project: project,
        configuration: configuration
      });
      return mapTab.init();
    }).then(function () {
      return mapTab.onAddClicked();
    }).then(function () {
      return mapTab.destroy();
    });
  });


});
