"use strict";
require("../../mocha-config");

var DataOverlay = require('../../../../main/js/map/data/DataOverlay');
var Project = require('../../../../main/js/map/data/Project');
var ServerConnector = require('../../ServerConnector-mock');

var logger = require('../../logger');

var chai = require('chai');
var assert = chai.assert;

describe('Project', function () {
  describe("constructor", function () {
    it("default", function () {
      return ServerConnector.sendGetRequest("testFiles/apiCalls/projects/sample/token=MOCK_TOKEN_ID&").then(function (res) {
        var project = new Project(res);
        assert.ok(project);

        assert.equal(project.getVersion(), "0");
        assert.equal(project.getId(), 14898);
        assert.equal(project.getName(), "UNKNOWN DISEASE MAP");
        assert.equal(project.getProjectId(), "sample");
        assert.deepEqual(project.getOverviewImages(), []);

        assert.equal(logger.getWarnings().length, 0);
      });
    });
    it("from Project obj", function () {
      return ServerConnector.sendGetRequest("testFiles/apiCalls/projects/sample/token=MOCK_TOKEN_ID&").then(function (res) {
        var tmpProject = new Project(res);

        var project = new Project(tmpProject);
        assert.ok(project);

        assert.equal(project.getVersion(), "0");
        assert.equal(project.getId(), 14898);
        assert.equal(project.getName(), "UNKNOWN DISEASE MAP");
        assert.equal(project.getProjectId(), "sample");
        assert.deepEqual(project.getOverviewImages(), []);

        assert.equal(logger.getWarnings().length, 0);
      });
    });
  });

  it("getDataOverlayById", function () {
    var project = helper.createProject();
    var overlay = helper.createOverlay();

    return project.getDataOverlayById(overlay.getId()).then(function () {
      assert.ok(false, 'expected rejection');
    }, function (exception) {
      assert.ok(exception);

      project.addDataOverlay(overlay);

      return project.getDataOverlayById(overlay.getId()).then(function (overlayResult) {
        assert.ok(overlayResult);
        assert.ok(overlayResult instanceof DataOverlay);
      });
    });
  });

});
